from django.apps import AppConfig


class MinimaluserConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "django_seriously.minimaluser"
